@@ -1,13 +1,8 @@
-#from sklearn import metrics
 from jinja2 import Environment, FileSystemLoader
-#import process.generate as preprocess
-#import train.generate as train
-from .train import train_generate
-from .process import preprocess_generate
 from .metrics import log_metrics
-
-#from .train.templates import temp_logistic_regression
-
+from huble.sklearn.process.templating import return_function as preprocess_generate
+from huble.sklearn.train.templates import return_function as train_generate
+from huble.sklearn.essentials.templates import return_function as essentials_generate
 from collections import defaultdict
  
 class Graph:
@@ -33,7 +28,7 @@ class Graph:
                 self.topologicalSortUtil(i, visited, stack)
         return(stack[::-1]) 
  
-def generate_file(graph):
+def generate_file(graph, colab=False):
     g = Graph(len(graph['nodes']))
     map = {}
     j=0
@@ -54,17 +49,27 @@ def generate_file(graph):
             if i == graph['nodes'][j]['id']:
                 steps_list[(graph['nodes'][j]['data']['name'])]=graph['nodes'][j]['data']['node_type']
 
-    for i in steps_list:
-        for node in graph['nodes']:
-            if i == node['data']['name']:
-                if steps_list[i]=='preprocess':
-                    script = preprocess_generate(node)
-                elif steps_list[i] == 'model':
-                    script = train_generate(node)
-                elif steps_list[i] == 'essential':
-                    script = "eeekjschj"
-                elif steps_list[i] == 'evalauate_model':
-                    script = "evaluate model"
+    with open("/content/output.py", "w") as f:
+        f.write("import huble\n")
+        
+        for i in steps_list:
+            for node in graph['nodes']:
+                if i == node['data']['name']:
+                    if steps_list[i]=='preprocess':
+                        f.write(preprocess_generate(node))
+                        f.write("\n")
+                    elif steps_list[i] == 'model':
+                        f.write(train_generate(node))
+                        f.write("\n")
+                    elif steps_list[i] == 'essential':
+                        f.write(essentials_generate(node))
+                        f.write("\n")
+                    elif steps_list[i] == 'evaluate_model':
+                        f.write("metrics = huble.util.evaluate_model(model=Model, test_dataset=test_dataset, 'classification' )")
+                        f.write("\n")
+                    elif steps_list[i] == 'primary_dataset':
+                        f.write(f"data=huble.util.load_dataset({node['data']['url']})")
+                        f.write("\n")
 
 
 
