@@ -5,7 +5,8 @@ from sklearn.impute import SimpleImputer
 import pandas as pd
 from scipy import stats
 import numpy as np
-from AutoClean import AutoClean
+# import AutoClean
+# from AutoClean import AutoClean
 
 def remove_nan_values(**params):
     data = params['data']
@@ -176,10 +177,10 @@ def clean_column_names(**params):
     data.rename(columns=lambda x: re.sub(match, "", str(x)))
     return data
 
-def clean_data(**params):
-    data = params['data']
-    df = AutoClean(data)
-    return df.output
+# def clean_data(**params):
+#     data = params['data']
+#     df = AutoClean(data)
+#     return df.output
 
 def clip(**params):
     data = params['data']
